# jsontrips [![PyPI version](https://badge.fury.io/py/jsontrips.svg)](https://badge.fury.io/py/jsontrips)

[![Build Status](https://travis-ci.org/mrmechko/jsontrips.svg?branch=master)](https://travis-ci.org/mrmechko/jsontrips)
